ResChunk

Struct ResChunk 

pub struct ResChunk {
    pub data: ResTypeValue,
}
Header that appears at the front of every data chunk in a resource.

Fields

data: ResTypeValue

The actual data of this chunk. The type is based on the rtype field. The type is a ResTypeValue, if not all of the bytes specified by [size] are read by the type, then the size will be padded so that end position is correct.

Implementations

Source

impl ResChunk

pub fn get_header_offset(pos: u64) -> u64

Subtracts the header size (8) from the current pos. Useful when a struct needs to find the start offset of the header. If pos is <= 8, 0 is returned.