ResTableRef

Struct ResTableRef 

pub struct ResTableRef {
    pub entry_index: u16,
    pub type_index: u8,
    pub package_index: u8,
}
This is a reference to a unique entry (a ResTable_entry structure) in a resource table. The value is structured as 0xpptteee, where pp is the package index, tt is the type index in that package, and eeee is the entry index in that type. The package and type values start a 1 for the first item, to help catch cases where they have been supplied.

Fields

entry_index: u16type_index: u8package_index: u8

Implementations

Source

impl ResTableRef

pub fn null() -> Self

Empty table reference

pub fn is_null(&self) -> bool

pub fn new(reference: u32) -> Self