pub struct ResTableStagedAlias {
pub entries: Vec<ResTableStagedAliasEntry>,
}Expand description
A map that allows rewriting staged (non-finalized) resource ids to their finalized counterparts
Fields
entries: Vec<ResTableStagedAliasEntry>Trait Implementations
Sourceimpl Clone for ResTableStagedAlias
impl Clone for ResTableStagedAlias
Sourcefn clone(&self) -> ResTableStagedAlias
fn clone(&self) -> ResTableStagedAlias
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResTableStagedAlias
impl Debug for ResTableStagedAlias
Sourceimpl HeaderSizeStatic for ResTableStagedAlias
impl HeaderSizeStatic for ResTableStagedAlias
Sourcefn header_size() -> usize
fn header_size() -> usize
Get the header size, does not include the size of the res chunk header, or any other parent
wrappers
Sourceimpl PartialEq for ResTableStagedAlias
impl PartialEq for ResTableStagedAlias
Sourceimpl Readable for ResTableStagedAlias
impl Readable for ResTableStagedAlias
impl StructuralPartialEq for ResTableStagedAlias