pub struct ResChunk {
pub data: ResTypeValue,
}Expand description
Header that appears at the front of every data chunk in a resource.
Fields
data: ResTypeValueThe actual data of this chunk. The type is based on the rtype field. The type is a
ResTypeValue, if not all of the bytes specified by [size] are read by the type, then
the size will be padded so that end position is correct.
Implementations